@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007 Free Software Foundation
+ * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Free Software Foundation
  *
  * Author: Nikos Mavroyanopoulos
  *
@@ -1203,6 +1203,7 @@ _gnutls_proc_cert_cert_req (gnutls_session_t session, opaque * data,
   int i, j;
   gnutls_pk_algorithm_t pk_algos[MAX_SIGN_ALGOS];
   int pk_algos_length;
+  gnutls_protocol_t ver = gnutls_protocol_get_version (session);
 
   cred = (gnutls_certificate_credentials_t)
     _gnutls_get_cred (session->key, GNUTLS_CRD_CERTIFICATE, NULL);
@@ -1250,6 +1251,19 @@ _gnutls_proc_cert_cert_req (gnutls_session_t session, opaque * data,
       return GNUTLS_E_UNKNOWN_PK_ALGORITHM;
     }
 
+  if (ver == GNUTLS_TLS1_2)
+    {
+      /* read supported hashes */
+      int hash_num;
+      DECR_LEN (dsize, 1);
+
+      hash_num = p[0] & 0xFF;
+      p++;
+
+      DECR_LEN (dsize, hash_num);
+      p+=hash_num;
+    }
+
   /* read the certificate authorities */
   DECR_LEN (dsize, 2);
   size = _gnutls_read_uint16 (p);
@@ -1652,16 +1666,10 @@ _gnutls_selected_certs_deinit (gnutls_session_t session)
 	{
 	  _gnutls_gcert_deinit (&session->internals.selected_cert_list[i]);
 	}
-      gnutls_free (session->internals.selected_cert_list);
       session->internals.selected_cert_list = NULL;
       session->internals.selected_cert_list_length = 0;
 
       _gnutls_gkey_deinit (session->internals.selected_key);
-      if (session->internals.selected_key)
-	{
-	  gnutls_free (session->internals.selected_key);
-	  session->internals.selected_key = NULL;
-	}
     }
 
   return;
