@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002, 2003, 2004, 2005 Free Software Foundation
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006 Free Software Foundation
  *
  * Author: Nikos Mavroyanopoulos
  *
@@ -836,7 +836,8 @@ _gnutls_xor (opaque * o1, opaque * o2, int length)
  * available.
  */
 int
-_gnutls_PRF (const opaque * secret, int secret_size, const char *label,
+_gnutls_PRF (gnutls_session_t session,
+	     const opaque * secret, int secret_size, const char *label,
 	     int label_size, const opaque * seed, int seed_size,
 	     int total_bytes, void *ret)
 {
@@ -845,6 +846,7 @@ _gnutls_PRF (const opaque * secret, int secret_size, const char *label,
   opaque s_seed[MAX_SEED_SIZE];
   opaque o1[MAX_PRF_BYTES], o2[MAX_PRF_BYTES];
   int result;
+  gnutls_protocol_t ver = gnutls_protocol_get_version (session);
 
   if (total_bytes > MAX_PRF_BYTES)
     {
@@ -863,38 +865,53 @@ _gnutls_PRF (const opaque * secret, int secret_size, const char *label,
   memcpy (s_seed, label, label_size);
   memcpy (&s_seed[label_size], seed, seed_size);
 
-  l_s = secret_size / 2;
-
-  s1 = &secret[0];
-  s2 = &secret[l_s];
-
-  if (secret_size % 2 != 0)
+  if (ver >= GNUTLS_TLS1_2)
     {
-      l_s++;
+      result =
+	_gnutls_P_hash (GNUTLS_MAC_SHA1, secret, secret_size,
+			s_seed, s_seed_size,
+			total_bytes, ret);
+      if (result < 0)
+	{
+	  gnutls_assert ();
+	  return result;
+	}
     }
-
-  result =
-    _gnutls_P_hash (GNUTLS_MAC_MD5, s1, l_s, s_seed, s_seed_size,
-		    total_bytes, o1);
-  if (result < 0)
+  else
     {
-      gnutls_assert ();
-      return result;
+      l_s = secret_size / 2;
+
+      s1 = &secret[0];
+      s2 = &secret[l_s];
+
+      if (secret_size % 2 != 0)
+	{
+	  l_s++;
+	}
+
+      result =
+	_gnutls_P_hash (GNUTLS_MAC_MD5, s1, l_s, s_seed, s_seed_size,
+			total_bytes, o1);
+      if (result < 0)
+	{
+	  gnutls_assert ();
+	  return result;
+	}
+
+      result =
+	_gnutls_P_hash (GNUTLS_MAC_SHA1, s2, l_s, s_seed, s_seed_size,
+			total_bytes, o2);
+      if (result < 0)
+	{
+	  gnutls_assert ();
+	  return result;
+	}
+
+      _gnutls_xor (o1, o2, total_bytes);
+
+      memcpy (ret, o1, total_bytes);
     }
 
-  result =
-    _gnutls_P_hash (GNUTLS_MAC_SHA1, s2, l_s, s_seed, s_seed_size,
-		    total_bytes, o2);
-  if (result < 0)
-    {
-      gnutls_assert ();
-      return result;
-    }
-
-  _gnutls_xor (o1, o2, total_bytes);
-
-  memcpy (ret, o1, total_bytes);
-
   return 0;			/* ok */
 
 }
@@ -936,7 +953,8 @@ gnutls_prf_raw (gnutls_session_t session,
 {
   int ret;
 
-  ret = _gnutls_PRF (session->security_parameters.master_secret,
+  ret = _gnutls_PRF (session,
+		     session->security_parameters.master_secret,
 		     TLS_MASTER_SIZE,
 		     label,
 		     label_size, (opaque *) seed, seed_size, outsize, out);
@@ -1000,7 +1018,7 @@ gnutls_prf (gnutls_session_t session,
 
   memcpy (seed + 2 * TLS_RANDOM_SIZE, extra, extra_size);
 
-  ret = _gnutls_PRF (session->security_parameters.master_secret,
+  ret = _gnutls_PRF (session, session->security_parameters.master_secret,
 		     TLS_MASTER_SIZE,
 		     label, label_size, seed, seedsize, outsize, out);
 
@@ -1022,7 +1040,7 @@ gnutls_prf (gnutls_session_t session,
  *
  * Return value: pointer to client random.
  **/
-const char *
+const void *
 gnutls_session_get_client_random (gnutls_session_t session)
 {
   return (char *) session->security_parameters.client_random;
@@ -1041,7 +1059,7 @@ gnutls_session_get_client_random (gnutls_session_t session)
  *
  * Return value: pointer to server random.
  **/
-const char *
+const void *
 gnutls_session_get_server_random (gnutls_session_t session)
 {
   return (char *) session->security_parameters.server_random;
@@ -1063,7 +1081,7 @@ gnutls_session_get_server_random (gnutls_session_t session)
  *
  * Return value: pointer to master secret.
  **/
-const char *
+const void *
 gnutls_session_get_master_secret (gnutls_session_t session)
 {
   return (char *) session->security_parameters.master_secret;
