@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004, 2005 Free Software Foundation
+ * Copyright (C) 2004, 2005, 2006 Free Software Foundation
  *
  * Author: Simon Josefsson
  *
@@ -38,6 +38,12 @@
 
 #include "utils.h"
 
+static void
+tls_log_func (int level, const char *str)
+{
+  fprintf (stderr, "|<%d>| %s", level, str);
+}
+
 /* A very basic TLS client, with anonymous authentication.
  */
 
@@ -95,6 +101,9 @@ client (void)
 
   gnutls_global_init ();
 
+  gnutls_global_set_log_function (tls_log_func);
+  gnutls_global_set_log_level (4711);
+
   gnutls_anon_allocate_client_credentials (&anoncred);
 
   /* Initialize TLS session
@@ -130,6 +139,9 @@ client (void)
       success ("client: Handshake was completed\n");
     }
 
+  success ("client: TLS version is: %s\n",
+	   gnutls_protocol_get_name (gnutls_protocol_get_version (session)));
+
   gnutls_record_send (session, MSG, strlen (MSG));
 
   ret = gnutls_record_recv (session, buffer, MAX_BUF);
@@ -144,15 +156,12 @@ client (void)
       goto end;
     }
 
-  if (debug)
+  printf ("- Received %d bytes: ", ret);
+  for (ii = 0; ii < ret; ii++)
     {
-      printf ("- Received %d bytes: ", ret);
-      for (ii = 0; ii < ret; ii++)
-	{
-	  fputc (buffer[ii], stdout);
-	}
-      fputs ("\n", stdout);
+      fputc (buffer[ii], stdout);
     }
+  fputs ("\n", stdout);
 
   gnutls_bye (session, GNUTLS_SHUT_RDWR);
 
@@ -233,6 +242,9 @@ server_start (void)
    */
   gnutls_global_init ();
 
+  gnutls_global_set_log_function (tls_log_func);
+  gnutls_global_set_log_level (4711);
+
   gnutls_anon_allocate_server_credentials (&anoncred);
 
   success ("Launched, generating DH parameters...\n");
@@ -301,6 +313,9 @@ server (void)
     }
   success ("server: Handshake was completed\n");
 
+  success ("server: TLS version is: %s\n",
+	   gnutls_protocol_get_name (gnutls_protocol_get_version (session)));
+
   /* see the Getting peer's information example */
   /* print_info(session); */
 
